@@ -2,7 +2,7 @@ use lib 'lib', '../lib';
 use Mojolicious::Lite;
 
 plugin 'AssetPack::Che' => {
-  pipes => [qw(Css CombineFile)],
+  pipes => [qw(Css CombineFile JavaScriptPacker)],
   process => {
     'main.css'=>['css/foo.css', 'css/bar.css',],
     't1.html'=>['templates/1.html', 'templates/2.html'],
